@@ -17,20 +17,21 @@ sub handler {
 
     plan $r, tests => 13;
 
-    ok( ! Apache::SizeLimit->_limits_are_exceeded(),
-        'check that _limits_are_exceeded() returns false without any limits set' );
+    {
+        local ($Apache::SizeLimit::Core::MAX_PROCESS_SIZE,
+               $Apache::SizeLimit::Core::MIN_SHARE_SIZE,
+               $Apache::SizeLimit::Core::MAX_UNSHARED_SIZE);
+        ok( ! Apache::SizeLimit->_limits_are_exceeded(),
+            'check that _limits_are_exceeded() returns false without any limits set' );
+    }
 
     {
         my ( $size, $shared ) = Apache::SizeLimit->_check_size();
         cmp_ok( $size, '>', 0, 'proc size is reported > 0' );
 
         {
-            # test with USE_SMAPS=0
-            my $smaps = $Apache::SizeLimit::USE_SMAPS;
-            $Apache::SizeLimit::USE_SMAPS = 0;
             my ( $size, $shared ) = Apache::SizeLimit->_check_size();
             cmp_ok( $size, '>', 0, 'proc size is reported > 0' );
-            $Apache::SizeLimit::USE_SMAPS = $smaps;
         }
 
     SKIP:
